@@ -389,7 +389,7 @@ void VoiceActingManager::OnGenerateFileNames()
 
 	// notify user that we are done and how many filenames were changed
 	char message[128] = { '\0' };
-	snprintf(message, sizeof(message), "File name generation complete. Modified %u messages.", modified_filenames);
+	snprintf(message, sizeof(message)-1, "File name generation complete. Modified %u messages.", modified_filenames);
 	MessageBox(message, "Woohoo!");
 }
 
